@@ -12,7 +12,7 @@
 
 
 /* FreeBSD uses a different identifier? what other BSDs? */
-#ifdef __FreeBSD__
+#if defined(__FreeBSD__) || defined(__FreeBSD_kernel__)
 #define SNDCTL_DSP_SETDUPLEX DSP_CAP_DUPLEX
 #endif
 
@@ -79,13 +79,8 @@ int esd_audio_open()
 
     /* set the sound driver audio format for playback */
     
-#if defined(WORDS_BIGENDIAN)
     value = test = ( (esd_audio_format & ESD_MASK_BITS) == ESD_BITS16 )
-        ? /* 16 bit */ AFMT_S16_BE : /* 8 bit */ AFMT_U8;
-#else
-    value = test = ( (esd_audio_format & ESD_MASK_BITS) == ESD_BITS16 )
-        ? /* 16 bit */ AFMT_S16_LE : /* 8 bit */ AFMT_U8;
-#endif
+        ? /* 16 bit */ AFMT_S16_NE : /* 8 bit */ AFMT_U8;
 
     if (ioctl(afd, SNDCTL_DSP_SETFMT, &test) == -1)
     {   /* Fatal error */
